/*    
	This file is part of ps2padlib.

    ps2padlib is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    ps2padlib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
*/
/*
	Dr Henry S Fortuna
*/

#include <stdio.h>
#include "pad.h"

int main(void)
{	
	
	int i = 0;
	
	// Variable to hold the axes values
	float xaxisL, xaxisLold;
	float yaxisL, yaxisLold;
	float xaxisR, xaxisRold;
	float yaxisR, yaxisRold;
	
	// Variables to hold the pressure values
	float crosspressure, 	crosspressureold;	
	float tripressure, 		tripressureold;
	float circlepressure, 	circlepressureold;
	float squarepressure, 	squarepressureold;
	float uppressure, 		uppressureold;
	float downpressure, 	downpressureold;
	float rightpressure, 	rightpressureold;
	float leftpressure, 	leftpressureold;
	float l1pressure, 		l1pressureold;
	float l2pressure, 		l2pressureold;
	float r1pressure, 		r1pressureold;
	float r2pressure, 		r2pressureold;
	
	// Initialise the Pad connected to port 1 of the PS2
	if(pad_init (PAD_0, /*PAD_INIT_DIGITAL  |*/ PAD_INIT_LOCK |PAD_INIT_ANALOGUE | PAD_INIT_PRESSURE) == 0)
	{
		printf("Unable to initialise the pads\n");
		pad_cleanup (PAD_0);
		exit(0);
	}
	
	// Print seme stats and enable the actuator if it is supported
	if(pad[0].actuator)
	{
		printf("Actuators Supported\n");
		enable_actuator(0, 1, 1);
	}
	else
	{
		printf("Actuators not supported\n");
	}


	// A simple game loop
	do
	{
		// Update the pad structures
		pad_update (PAD_0);
		
		// Turn the actuators on/off with cross and circle
		if(pad[0].actuator)
		{
			if(pad[0].pressed & PAD_CROSS)set_actuator(0, 1, 255);
			if(pad[0].pressed & PAD_CIRCLE)set_actuator(0, 0, 0);
		}
			
		// Print out the keys that have been pressed
		if(pad[0].pressed & PAD_START)printf("Start Pressed %d\n", i++);
		if(pad[0].pressed & PAD_SELECT)printf("Select released %d\n", i++);
		if(pad[0].pressed & PAD_UP)printf("Up Pressed %d\n", i++);
		if(pad[0].pressed & PAD_DOWN)printf("Down Pressed %d\n", i++);
		if(pad[0].pressed & PAD_LEFT)printf("Left Pressed %d\n", i++);
		if(pad[0].pressed & PAD_RIGHT)printf("Right Pressed %d\n", i++);
		if(pad[0].pressed & PAD_L1)printf("L1 Pressed %d\n", i++);
		if(pad[0].pressed & PAD_L2)printf("L2 Pressed %d\n", i++);
		if(pad[0].pressed & PAD_L3)printf("L3 Pressed %d\n", i++);
		if(pad[0].pressed & PAD_R1)printf("R1 Pressed %d\n", i++);
		if(pad[0].pressed & PAD_R2)printf("R2 Pressed %d\n", i++);
		if(pad[0].pressed & PAD_R3)printf("R3 Pressed %d\n", i++);
		if(pad[0].pressed & PAD_CROSS)printf("Cross pressed %d\n", i++);
		if(pad[0].pressed & PAD_SQUARE)printf("Square pressed %d\n", i++);
		if(pad[0].pressed & PAD_TRI)printf("Triangle pressed %d\n", i++);
		if(pad[0].pressed & PAD_CIRCLE)printf("Circle pressed %d\n", i++);
		
		// Print out the keys that have been released
		if(pad[0].released & PAD_START)printf("Start Released %d\n", i++);
		if(pad[0].released & PAD_SELECT)printf("Select released %d\n", i++);
		if(pad[0].released & PAD_UP)printf("Up Released %d\n", i++);
		if(pad[0].released & PAD_DOWN)printf("Down Released %d\n", i++);
		if(pad[0].released & PAD_LEFT)printf("Left Released %d\n", i++);
		if(pad[0].released & PAD_RIGHT)printf("Right Released %d\n", i++);
		if(pad[0].released & PAD_L1)printf("L1 Released %d\n", i++);
		if(pad[0].released & PAD_L2)printf("L2 Released %d\n", i++);
		if(pad[0].released & PAD_L3)printf("L3 Released %d\n", i++);
		if(pad[0].released & PAD_R1)printf("R1 Released %d\n", i++);
		if(pad[0].released & PAD_R2)printf("R2 Released %d\n", i++);
		if(pad[0].released & PAD_R3)printf("R3 Released %d\n", i++);
		if(pad[0].released & PAD_CROSS)printf("Cross released %d\n", i++);
		if(pad[0].released & PAD_SQUARE)printf("Square released %d\n", i++);
		if(pad[0].released & PAD_TRI)printf("Triangle released %d\n", i++);
		if(pad[0].released & PAD_CIRCLE)printf("Circle released %d\n", i++);
		
		
		// If in analogue mode, print out any change in the axis values
		if(pad[0].initflags & PAD_INIT_ANALOGUE)
		{
			xaxisLold = xaxisL;
			xaxisL = pad[0].axes[PAD_AXIS_LX];
			if(xaxisLold != xaxisL)printf("AXIS_LX = %f\n", xaxisL);
		
			yaxisLold = yaxisL;
			yaxisL = pad[0].axes[PAD_AXIS_LY];
			if(yaxisLold != yaxisL)printf("AXIS_LY = %f\n", yaxisL);
		
			xaxisRold = xaxisR;
			xaxisR = pad[0].axes[PAD_AXIS_RX];
			if(xaxisRold != xaxisR)printf("AXIS_RX = %f\n", xaxisR);
		
			yaxisRold = yaxisR;
			yaxisR = pad[0].axes[PAD_AXIS_RY];
			if(yaxisRold != yaxisR)printf("AXIS_RY = %f\n", yaxisR);
		}
		
		// If in pressure mode print out any change in the key pressures
		if(pad[0].initflags & PAD_INIT_PRESSURE)
		{			
			crosspressureold = crosspressure;
			crosspressure = pad[0].pressures[PAD_PCROSS];
			if(crosspressure != crosspressureold)printf("Cross pressure %f\n", crosspressure);
		
			tripressureold = tripressure;
			tripressure = pad[0].pressures[PAD_PTRI];
			if(tripressure != tripressureold)printf("Triangle pressure %f\n", tripressure);
			
			circlepressureold = circlepressure;
			circlepressure = pad[0].pressures[PAD_PCIRCLE];
			if(circlepressure != circlepressureold)printf("Circle pressure %f\n", circlepressure);
			
			squarepressureold = squarepressure;
			squarepressure = pad[0].pressures[PAD_PSQUARE];
			if(squarepressure != squarepressureold)printf("Square pressure %f\n", squarepressure);
		
			uppressureold = uppressure;
			uppressure = pad[0].pressures[PAD_PUP];
			if(uppressure != uppressureold)printf("Up pressure %f\n", uppressure);
			
			downpressureold = downpressure;
			downpressure = pad[0].pressures[PAD_PDOWN];
			if(downpressure != downpressureold)printf("Down pressure %f\n", downpressure);
			
			rightpressureold = rightpressure;
			rightpressure = pad[0].pressures[PAD_PRIGHT];
			if(rightpressure != rightpressureold)printf("Right pressure %f\n", rightpressure);
			
			leftpressureold = leftpressure;
			leftpressure = pad[0].pressures[PAD_PLEFT];
			if(leftpressure != leftpressureold)printf("Left pressure %f\n", leftpressure);
			
			l1pressureold = l1pressure;
			l1pressure = pad[0].pressures[PAD_PL1];
			if(l1pressure != l1pressureold)printf("L1 pressure %f\n", l1pressure);
			
			l2pressureold = l2pressure;
			l2pressure = pad[0].pressures[PAD_PL2];
			if(l2pressure != l2pressureold)printf("L2 pressure %f\n", l2pressure);
			
			r1pressureold = r1pressure;
			r1pressure = pad[0].pressures[PAD_PR1];
			if(r1pressure != r1pressureold)printf("R1 pressure %f\n", r1pressure);
			
			r2pressureold = r2pressure;
			r2pressure = pad[0].pressures[PAD_PR2];
			if(r2pressure != r2pressureold)printf("R2 pressure %f\n", r2pressure);
		}
		
		
	// Press start and select together to end the loop	
	}while(!((pad[0].buttons & PAD_START)&&(pad[0].buttons & PAD_SELECT)));
	
	// Release the pad device and clean up.
	pad_cleanup (PAD_0);
	
	return 0;
	
}
